@@ -1,23 +1,14 @@
 /*
- *
- * Copyright (C) 2006 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 1998-2007 Sebastian Trueg <trueg@k3b.org>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _K3B_VIDEODVD_TIME_H_
 #define _K3B_VIDEODVD_TIME_H_
 
 #include "k3b_export.h"
 
-#include <QtCore/QString>
+#include <QString>
 
 namespace K3b {
     namespace VideoDVD
