@@ -1,17 +1,8 @@
 /*
- *
- * $Id$
- * Copyright (C) 2003-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+    SPDX-FileCopyrightText: 1998-2008 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "k3boggvorbisdecoder.h"
 #include "k3bplugin_i18n.h"
 
@@ -26,7 +17,7 @@
 #include <vorbis/codec.h>
 #include <vorbis/vorbisfile.h>
 
-K3B_EXPORT_PLUGIN(k3boggvorbisdecoder, K3bOggVorbisDecoderFactory)
+K_PLUGIN_CLASS_WITH_JSON(K3bOggVorbisDecoderFactory, "k3boggvorbisdecoder.json")
 
 class K3bOggVorbisDecoder::Private
 {
